==> smsaero_smpp-1.0.0.tar.gz: smsaero_smpp-1.0.0/setup.py <==
"""Setup script for the SmsAero API client package."""

from setuptools import setup, find_packages


with open("README.md", "r", encoding="utf-8") as file:
    long_description = file.read()


setup(
    name="smsaero_smpp",
    version="1.0.0",
    description="SMS Aero SMPP Lib",
    keywords=[
        "smsaero",
        "smpp",
        "smsaero_smpp",
        "sms",
        "hlr",
        "viber",
    ],
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="SmsAero",
    author_email="admin@smsaero.ru",
    maintainer="SmsAero Team",
    maintainer_email="support@smsaero.ru",
    help_center="https://smsaero.ru/support/",
    url="https://github.com/smsaero/smsaero_python_smpp_example/",
    project_urls={
        "Homepage": "https://smsaero.ru/",
        "Repository": "https://github.com/smsaero/smsaero_python_smpp_example/",
        "Bug Tracker": "https://github.com/smsaero/smsaero_python_smpp_example/issues",
        "Help Center": "https://smsaero.ru/support/",
    },
    download_url="https://github.com/smsaero/smsaero_python_smpp_example/archive/refs/tags/1.0.0.tar.gz",
    license="MIT",
    packages=find_packages(exclude=["tests", "tests.*"]),
    python_requires=">=3.6",
    include_package_data=True,
    install_requires=[
        "setuptools",
        "smpplib",
        "phonenumbers",
    ],
    extras_require={
        "dev": [
            "pytest >= 8.2.2",
            "flake8 >= 7.1.0",
            "ruff >= 0.4.10",
            "pylint >= 3.2.4",
            "tox >= 4.15.1",
            "mypy >= 1.10.0",
            "coverage >= 7.5.4",
            "bandit >= 1.7.9",
            "build >= 1.2.1",
            "twine >= 5.1.1",
        ],
    },
    zip_safe=False,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Programming Language :: Python :: 3.14",
        "Programming Language :: Python :: Implementation :: CPython",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Communications :: Telephony",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    platforms=["any"],
    entry_points={
        "console_scripts": [
            "smsaero_smpp_send=smsaero_smpp.cmd_send:main",
            "smsaero_smpp_status=smsaero_smpp.cmd_status:main",
        ],
    },
    options={
        "bdist_wheel": {"universal": True},
    },
)

==> smsaero_smpp-1.0.1.tar.gz: smsaero_smpp-1.0.1/setup.py <==
"""Setup script for the SmsAero API client package."""

from setuptools import setup, find_packages


with open("README.md", "r", encoding="utf-8") as file:
    long_description = file.read()


setup(
    name="smsaero_smpp",
    version="1.0.1",
    description="SMS Aero SMPP Lib",
    keywords=[
        "smsaero",
        "smpp",
        "smsaero_smpp",
        "sms",
        "hlr",
        "viber",
    ],
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="SmsAero",
    author_email="admin@smsaero.ru",
    maintainer="SmsAero Team",
    maintainer_email="support@smsaero.ru",
    help_center="https://smsaero.ru/support/",
    url="https://github.com/smsaero/smsaero_python_smpp/",
    project_urls={
        "Homepage": "https://smsaero.ru/",
        "Repository": "https://github.com/smsaero/smsaero_python_smpp/",
        "Bug Tracker": "https://github.com/smsaero/smsaero_python_smpp/issues",
        "Help Center": "https://smsaero.ru/support/",
    },
    download_url="https://github.com/smsaero/smsaero_python_smpp/archive/refs/tags/1.0.1.tar.gz",
    license="MIT",
    packages=find_packages(exclude=["tests", "tests.*"]),
    python_requires=">=3.6",
    include_package_data=True,
    install_requires=[
        "setuptools",
        "smpplib",
        "phonenumbers",
    ],
    extras_require={
        "dev": [
            "pytest >= 8.2.2",
            "flake8 >= 7.1.0",
            "ruff >= 0.4.10",
            "pylint >= 3.2.4",
            "tox >= 4.15.1",
            "mypy >= 1.10.0",
            "coverage >= 7.5.4",
            "bandit >= 1.7.9",
            "build >= 1.2.1",
            "twine >= 5.1.1",
        ],
    },
    zip_safe=False,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Programming Language :: Python :: 3.14",
        "Programming Language :: Python :: Implementation :: CPython",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Communications :: Telephony",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    platforms=["any"],
    entry_points={
        "console_scripts": [
            "smsaero_smpp_send=smsaero_smpp.cmd_send:main",
            "smsaero_smpp_status=smsaero_smpp.cmd_status:main",
        ],
    },
    options={
        "bdist_wheel": {"universal": True},
    },
)
